@@ -5,17 +5,19 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudformation._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
+import cdk_iam_floyd._jsii
 import constructs._jsii
-import iam_floyd._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk-ssm-document", "1.2.0", __name__[0:-6], "cdk-ssm-document@1.2.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "cdk-ssm-document", "1.3.0", __name__[0:-6], "cdk-ssm-document@1.3.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
